==> egroupware-epl_14.1.20150210.orig.tar.gz: egroupware/admin/setup/setup.inc.php <==
<?php
/**
 * EGroupware - Admin
 *
 * @link http://www.egroupware.org
 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
 * @package admin
 * @subpackage setup
 * @version $Id: setup.inc.php 47348 2014-06-24 10:00:50Z ralfbecker $
 */

$setup_info['admin']['name']      = 'admin';
$setup_info['admin']['version']   = '14.1';
$setup_info['admin']['app_order'] = 1;
$setup_info['admin']['tables']    = array('egw_admin_queue','egw_admin_remote');
$setup_info['admin']['enable']    = 1;
$setup_info['admin']['index']   = 'admin.admin_ui.index&ajax=true';

$setup_info['admin']['author'][] = array(
	'name'  => 'eGroupWare coreteam',
	'email' => 'egroupware-developers@lists.sourceforge.net'
);

$setup_info['admin']['maintainer'][] = array(
	'name'  => 'eGroupWare coreteam',
	'email' => 'egroupware-developers@lists.sourceforge.net',
	'url'   => 'www.egroupware.org'
);

$setup_info['admin']['license']  = 'GPL';
$setup_info['admin']['description'] = 'EGroupware administration application';

/* The hooks this app includes, needed for hooks registration */
$setup_info['admin']['hooks'] = array(
	'acl_manager',
	'after_navbar',
	'config_validate',
	'deleteaccount',
	'topmenu_info'
);
$setup_info['admin']['hooks']['admin'] = 'admin_hooks::all_hooks';
$setup_info['admin']['hooks']['sidebox_menu'] = 'admin_hooks::all_hooks';
$setup_info['admin']['hooks']['edit_user'] = 'admin_hooks::edit_user';

// add account tab to addressbook.edit
$setup_info['admin']['hooks']['addressbook_edit'] = 'admin.admin_account.addressbook_edit';

/* Dependencies for this app to work */
$setup_info['admin']['depends'][] = array(
	'appname' => 'phpgwapi',
	'versions' => Array('14.1')
);
$setup_info['admin']['depends'][] = array(
	'appname' => 'etemplate',
	'versions' => Array('14.1')
);

==> egroupware-epl_14.3.20160708.orig.tar.gz: egroupware/admin/setup/setup.inc.php <==
<?php
/**
 * EGroupware - Admin
 *
 * @link http://www.egroupware.org
 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
 * @package admin
 * @subpackage setup
 * @version $Id$
 */

$setup_info['admin']['name']      = 'admin';
$setup_info['admin']['version']   = '14.3.001';
$setup_info['admin']['app_order'] = 1;
$setup_info['admin']['tables']    = array('egw_admin_queue','egw_admin_remote');
$setup_info['admin']['enable']    = 1;
$setup_info['admin']['index']   = 'admin.admin_ui.index&ajax=true';

$setup_info['admin']['author'][] = array(
	'name'  => 'eGroupWare coreteam',
	'email' => 'egroupware-developers@lists.sourceforge.net'
);

$setup_info['admin']['maintainer'][] = array(
	'name'  => 'eGroupWare coreteam',
	'email' => 'egroupware-developers@lists.sourceforge.net',
	'url'   => 'www.egroupware.org'
);

$setup_info['admin']['license']  = 'GPL';
$setup_info['admin']['description'] = 'EGroupware administration application';

/* The hooks this app includes, needed for hooks registration */
$setup_info['admin']['hooks'] = array(
	'acl_manager',
	'config_validate',
	'deleteaccount',
	'topmenu_info'
);
$setup_info['admin']['hooks']['admin'] = 'admin_hooks::all_hooks';
$setup_info['admin']['hooks']['sidebox_menu'] = 'admin_hooks::all_hooks';
$setup_info['admin']['hooks']['edit_user'] = 'admin_hooks::edit_user';

// add account tab to addressbook.edit
$setup_info['admin']['hooks']['addressbook_edit'] = 'admin.admin_account.addressbook_edit';

/* Dependencies for this app to work */
$setup_info['admin']['depends'][] = array(
	'appname' => 'phpgwapi',
	'versions' => Array('14.1')
);
$setup_info['admin']['depends'][] = array(
	'appname' => 'etemplate',
	'versions' => Array('14.1')
);
